# FritzBox Tray

A system tray application for interacting with FRITZ!Box devices.

![fritzbox-tray](https://user-images.githubusercontent.com/48277853/211208943-1cbb41fb-60a7-44d1-a697-5d0493bb167c.png)

## Features

- Display current external IP address
- Reconnect FRITZ!Box device
- Quit application

## Requirements

- Python 3.6 or higher

## Installation

To install FritzBox Tray, run the following command:

    pip install fritzbox-tray

## Usage

To start FritzBox Tray, run the following command:

    fritzbox-tray

This will start the application and place an icon in the system tray. Right-clicking on the icon will display a menu with the following options:

 - **Display Current IP Address**: Display a notification with the current external IP address of the FRITZ!Box device
 - **Reconnect**: Terminate and re-establish the Internet connection of the FRITZ!Box device
 - **Quit**: Close the application

## Contribution

Pull requests and issues are welcome.

## License

This project is licensed under the GNU General Public License v3.0.

See the [LICENSE](https://github.com/aviolaris/fritzbox-tray/blob/master/LICENSE.md) file for details.


